pub struct ShapeThresholds {
pub markdown_table_min_cols: usize,
pub array_of_objects_min_items: usize,
pub array_of_objects_min_key_stability: f32,
pub flat_object_min_fields: usize,
}Fields
markdown_table_min_cols: usizeApply csv_from_md only if the markdown table has at least this many columns.
array_of_objects_min_items: usizeApply csv only if the array has at least this many objects.
array_of_objects_min_key_stability: f32Minimum mean key-stability across items (0.0–1.0) for csv encoding.
flat_object_min_fields: usizeApply kv only if the flat object has at least this many fields.